Index: runtime/vm/stub_code.h |
diff --git a/runtime/vm/stub_code.h b/runtime/vm/stub_code.h |
index 7d0dd14534fec8387dee5500a9ee8969e8d9137d..3a2cea016c318a54943937b67e170f47f91e6677 100644 |
--- a/runtime/vm/stub_code.h |
+++ b/runtime/vm/stub_code.h |
@@ -25,7 +25,8 @@ class Deserializer; |
#if !defined(TARGET_ARCH_DBC) |
#define VM_STUB_CODE_LIST(V) \ |
V(GetStackPointer) \ |
- V(JumpToExceptionHandler) \ |
+ V(JumpToFrame) \ |
+ V(RunExceptionHandler) \ |
V(UpdateStoreBuffer) \ |
V(PrintStopMessage) \ |
V(CallToRuntime) \ |
@@ -73,6 +74,7 @@ class Deserializer; |
#define VM_STUB_CODE_LIST(V) \ |
V(LazyCompile) \ |
V(OptimizeFunction) \ |
+ V(RunExceptionHandler) \ |
V(FixCallersTarget) \ |
V(Deoptimize) \ |
V(DeoptimizeLazyFromReturn) \ |
@@ -138,8 +140,8 @@ class StubCode : public AllStatic { |
// transitioning into dart code. |
static bool InInvocationStub(uword pc); |
- // Check if the specified pc is in the jump to exception handler stub. |
- static bool InJumpToExceptionHandlerStub(uword pc); |
+ // Check if the specified pc is in the jump to frame stub. |
+ static bool InJumpToFrameStub(uword pc); |
// Returns NULL if no stub found. |
static const char* NameOfStub(uword entry_point); |